@@ -2,7 +2,7 @@
  * This file is part of qdacco
  * qdacco: offline Dacco Catalan <-> English dictionary
  *
- * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2011, 2013, 2015
+ * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2011, 2013, 2015, 2020
  *      Carles Pina i Estany <carles@pina.cat>
  *
  * qdacco is free software; you can redistribute it and/or modify
@@ -22,10 +22,10 @@
 #include "main.h"
 
 #include "AuxiliarGUI.h"
-#include "about.h"
-#include "configure.h"
-#include "textbrowser.h"
-#include "trayicon.h"
+#include "About.h"
+#include "Configure.h"
+#include "TextBrowser.h"
+#include "TrayIcon.h"
 
 #include "nongui/StructureList.h"
 
@@ -33,32 +33,28 @@
 
 Main::Main(QWidget *)  //parent
 {
-        ui.setupUi(this);
+	ui.setupUi(this);
 	ui.paraula->setParent(this);
 	ui.llistat->setParent(this);
-	ui.definicio->setFather(this);
+    ui.definicio->setParent(this);
 
 	resize(QSize(270,300));
 
 	installEventFilter(this);
 
-	m_numberFound=0;
-
 	m_cat_eng = new QToolButton;
-	m_cat_eng->setText(tr("cat->eng"));
+	m_cat_eng->setText(tr("cat → eng"));
 	m_cat_eng->setCheckable(1);
 	ui.toolBar->addWidget(m_cat_eng);
 
 	m_eng_cat = new QToolButton;
-	m_eng_cat->setText(tr("eng->cat"));
+	m_eng_cat->setText(tr("eng → cat"));
 	m_eng_cat->setCheckable(1);
 	ui.toolBar->addWidget(m_eng_cat);
 
 	ui.toolBar->addSeparator();
 
-	ui.definicio->setProcess(&m_browser);
-
-	QAction *copy = ui.toolBar->addAction(QIcon(":icons/editcopy.png"),tr("Copy"));
+    QAction *copy = ui.toolBar->addAction(QIcon(":icons/editcopy.png"),tr("Copy"));
 	QAction *paste = ui.toolBar->addAction(QIcon(":icons/editpaste.png"),tr("Paste"));
 	connect(copy,SIGNAL(triggered()),this,SLOT(copy_definition()));
 	connect(paste,SIGNAL(triggered()),this,SLOT(paste_word()));
@@ -79,7 +75,7 @@ Main::Main(QWidget *)  //parent
 
 	connect(&m_festival,SIGNAL(error(QProcess::ProcessError)),this,SLOT(FestivalError(QProcess::ProcessError)));
 	connect(&m_festival,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(FestivalFinished(int,QProcess::ExitStatus)));
-	connect(&m_browser,SIGNAL(error(QProcess::ProcessError)),this,SLOT(BrowserError(QProcess::ProcessError)));
+    connect(ui.definicio,SIGNAL(browserFailed()),this,SLOT(showBrowserError()));
 	
 	carrega_config(1);
 
@@ -104,10 +100,6 @@ void Main::FestivalError(QProcess::ProcessError)
 	showError(tr("Error executing Festival. Please check the FAQ for help with this issue"));
 }
 
-void Main::BrowserError(QProcess::ProcessError) {
-	showError(tr("Error executing browser. Please check the FAQ for help with this issue"));
-}
-
 void Main::FestivalExecuteEntry() {
 	QString arguments="";
 
@@ -246,7 +238,7 @@ bool Main::eventFilter(QObject *, QEvent *event) //obj
 		type!=QEvent::User+Auxiliar::KeyUp() &&
 		type!=QEvent::User+Auxiliar::KeyNextPage() &&
 		type!=QEvent::User+Auxiliar::KeyPrevPage()) {
-			return NULL;
+            return false;
 	}
 
 	if (ui.llistat->isVisible()) {
@@ -268,7 +260,7 @@ void Main::buscarEnter()
 	if (ui.llistat->isVisible()) {
 		QListWidgetItem *item;
 		item = ui.llistat->currentItem();
-		if (item!=NULL) {
+        if (item!=nullptr) {
 			ui.paraula->setText(item->text());
 		}
 	}
@@ -306,7 +298,6 @@ void Main::paraulaChanged(const QString &paraula)
 	ui.definicio->hide();
 	ui.llistat->clear();
 	UpdateList();
-	m_numberFound=0;
 
 	if (ui.llistat->count()==1) {
 		ui.llistat->setCurrentRow(0);
@@ -317,11 +308,11 @@ void Main::paraulaChanged(const QString &paraula)
 	}
 }
 
-int lib2class(QString q) { //bridge
+void lib2class(QString q) { //bridge
 	((Main*)AuxiliarGUI::m)->AddEntryToGUI(q);
 }
 
-int Main::AddEntryToGUI(QString q) {
+void Main::AddEntryToGUI(QString q) {
 	ui.llistat->insertItem(999999999,q);
 }
 
@@ -332,7 +323,7 @@ void Main::UpdateList() {
 	handler.setIgnoreAccents(m_IgnoreAccents);
 
 	AuxiliarGUI::m=this;
-	int (*ptrFunction)(QString)=NULL;
+    void (*ptrFunction)(QString)=nullptr;
 	ptrFunction = lib2class;
 
 	handler.setAddFunction(ptrFunction);
@@ -359,7 +350,7 @@ void Main::UpdateList() {
 		return;
         }
 
-	letter=lletra_buscar(search);
+    letter=removeAccents(search);
 	QFile xmlFile(m_directori_usuari+"/"+idioma+"/"+letter+".dic");
 
 	if (!xmlFile.exists()) {
@@ -379,8 +370,6 @@ void Main::UpdateList() {
 
 		WordData d = handler.getWordData();
 
-		ui.definicio->setPlainText("");
-
 		ui.definicio->setPlainText("");
 		m_searched=search;
 		selectItem();
@@ -419,7 +408,7 @@ void Main::treballaBuscar() {
         }
         else {  //TODO: clean this crazy if-else!
 
-		lletra=lletra_buscar(buscar);
+        lletra=removeAccents(buscar);
 		QFile xmlFile(m_directori_usuari+"/"+idioma+"/"+lletra+".dic");
 
 
@@ -434,7 +423,7 @@ void Main::treballaBuscar() {
 			reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
 			reader.setContentHandler( &handler );
 
-			handler.setParaula(buscar_orig);
+			handler.setEntryWanted(buscar_orig);
 
 			reader.parse(source);
 
@@ -442,24 +431,14 @@ void Main::treballaBuscar() {
 
 			ui.definicio->setPlainText("");
 
-		        if (d.getNum()!=0) {
+            if (d.found()) {
 				ui.definicio->show();
 				ui.llistat->hide();
 
-				QString definicio;
-				
-				for (int i=0;i<d.getNum();i++) {
-					if (i==0) {
-						definicio=d.getEntry(i);
-					}
-					else {
-						definicio+="<BR><BR>"+d.getEntry(i);
-					}
-				}
+                QString definicio = d.getHTMLEntry();
 				ui.definicio->setHtml(definicio);
 			}
-			
-			else if (d.getNum()==0) {
+            else {
 				//No word found or buscar == 1: we show the list
 				
 				ui.definicio->setPlainText("");
@@ -469,17 +448,15 @@ void Main::treballaBuscar() {
 				
 				m_searched=buscar_orig;
 				selectItem();
-				if (d.getNum()==0) {
+                if (!d.found()) {
 					showError(tr("Exact match not found"));
 				}
 			}
-			m_numberFound=d.getNum();
 		}
         }
 }
 
 void Main::posarApunt (int all) {
-	m_numberFound=0;
         ui.llistat->clear();
         ui.llistat->hide();
 	ui.definicio->show();
@@ -496,7 +473,6 @@ void Main::posarApunt (int all) {
 }
 
 int Main::isValidWord(QString &q) {
-        QChar first;
         //We transform the word to not-capital
         //We check that first letter is a letter
         //We delete space before word
@@ -511,31 +487,29 @@ int Main::isValidWord(QString &q) {
         return (q.length()>0 && q.at(0).isLetter());
 }
 
-char Main::lletra_buscar(QString q) {
-        QChar a;
+char Main::removeAccents(const QString& q) {
+        QChar c = q.at(0);
 
-        if (q.at(0)=='' || q.at(0)=='' || q.at(0)=='' || q.at(0)=='') return 'a';
-        if (q.at(0)=='' || q.at(0)=='' || q.at(0)=='' || q.at(0)=='') return 'e';
-        if (q.at(0)==''  || q.at(0)=='' || q.at(0)=='' || q.at(0)=='') return 'i';
-        if (q.at(0)=='' || q.at(0)=='' || q.at(0)=='' || q.at(0)=='') return 'o';
-        if (q.at(0)=='' || q.at(0)=='' || q.at(0)=='' || q.at(0)=='') return 'u';
+        if (c==L'à' || c==L'á' || c==L'â' || c==L'ä') return 'a';
+        if (c==L'è' || c==L'é' || c==L'ê' || c==L'ë') return 'e';
+        if (c==L'ì'  || c==L'í' || c==L'î' || c==L'ï') return 'i';
+        if (c==L'ò' || c==L'ó' || c==L'ô' || c==L'ö') return 'o';
+        if (c==L'ù' || c==L'ú' || c==L'û' || c==L'ü') return 'u';
 
-        if (q.at(0)=='') return 'c';
+        if (q.at(0)==L'ç') return 'c';
 
-        a=q.at(0);
-
-        return (a.toLatin1());
+        return (c.toLatin1());
 }
 
 void Main::selectItem()
 {
 	QListWidgetItem *item;
 
-	//Si s, s a la fila 0
+	//Si és, és a la fila 0
 	
 	item = ui.llistat->item(0);
 
-	if (item!=NULL) {
+    if (item!=nullptr) {
 		if (item->text().compare(m_searched)==0) {
 			ui.llistat->setCurrentRow(0);
 		}
@@ -602,8 +576,8 @@ void Main::carrega_config(int )
 
 		ui.definicio->setBrowser(browser);
 
-                Auxiliar::debug("Load config");
-                Auxiliar::debug("Directory: "+m_directori_usuari);
+        Auxiliar::debug("Load config");
+        Auxiliar::debug("Directory: "+m_directori_usuari);
                 
 		posa_idioma();
         }
@@ -686,6 +660,9 @@ void Main::showError(QString text) {
 	ui.actiu->show();
 }
 
+void Main::showBrowserError() {
+    showError(tr("Error executing browser. Please check the FAQ for help with this issue"));
+}
 
 void Main::showMessage(QString text) {
 	ui.actiu->setText("<CENTER>"+text+"</CENTER>");
@@ -700,5 +677,6 @@ void Main::restaura() {
 }
 
 void Main::quit() {
+    // This is not the usual way to exit a Qt application!
 	exit(0);
 }
