@@ -26,14 +26,14 @@
 #include <QMessageBox>
 
 #include "AuxiliarGUI.h"
-#include "configure.h"
-#include "loadconfig.h"
+#include "Configure.h"
+#include "LoadConfig.h"
 #include "main.h"
-#include "oneinstance.h"
-#include "trayicon.h"
+#include "OneInstance.h"
+#include "TrayIcon.h"
 
 //qdaccolib
-#include <nongui/auxiliar.h>
+#include <nongui/Auxiliar.h>
 
 int main(int argc, char **argv)
 {
@@ -58,7 +58,7 @@ int main(int argc, char **argv)
 	std::cout << "This program comes with ABSOLUTELY NO WARRANTY" << std::endl;
 	std::cout << "This is free software, and you are welcome to redistribute it" << std::endl;
 	std::cout << "under certain conditions" << std::endl;
-        std::cout << "Program: GPL v3. Data: LGPL" << std::endl;
+        std::cout << "Software: GPL v3. Data: LGPL" << std::endl;
 
 	QSettings qs("dacco","qdacco");
 	int idioma = qs.value("/dacco/idioma_per_defecte",1).toInt();
@@ -108,7 +108,7 @@ int main(int argc, char **argv)
 	qs.sync();
 
 	LoadConfig loadconfig;
-	oneInstance myOneInstance;
+	OneInstance myOneInstance;
 
 	int single = loadconfig.getSingleInstance();
 	
